This is a live mirror of the Perl 5 development currently hosted at https://github.com/perl/perl5
rename cygwin32 to cygwin (from Eric Fifer <EFifer@sanwaint.com>)
authorGurusamy Sarathy <gsar@cpan.org>
Sun, 1 Aug 1999 20:29:17 +0000 (20:29 +0000)
committerGurusamy Sarathy <gsar@cpan.org>
Sun, 1 Aug 1999 20:29:17 +0000 (20:29 +0000)
p4raw-id: //depot/perl@3852

21 files changed:
AUTHORS
EXTERN.h
INSTALL
MAINTAIN
Makefile.SH
Porting/patchls
README.cygwin
README.win32
XSUB.h
cygwin/Makefile.SHs
ext/DynaLoader/dl_cygwin.xs
ext/POSIX/POSIX.xs
ext/SDBM_File/sdbm/pair.c
hints/cygwin.sh
lib/ExtUtils/MM_Cygwin.pm
makedepend.SH
perl.h
pod/perl.pod
pod/perlport.pod
pp_sys.c
util.c

diff --git a/AUTHORS b/AUTHORS
index 47669ed..ed52400 100644 (file)
--- a/AUTHORS
+++ b/AUTHORS
@@ -82,7 +82,7 @@ cgi           lstein
 complex                jhi,raphael
 cpan           k
 cxux           tom.horsley
-cygwin32       win32
+cygwin         win32
 dec_osf                jhi,spider
 dgux           roderick
 doc            tchrist
index 1aa89e6..9d31124 100644 (file)
--- a/EXTERN.h
+++ b/EXTERN.h
@@ -40,7 +40,7 @@
 #      define dEXTCONST const
 #    endif
 #  else
-#    if defined(CYGWIN32) && defined(USEIMPORTLIB)
+#    if defined(CYGWIN) && defined(USEIMPORTLIB)
 #      define EXT extern __declspec(dllimport)
 #      define dEXT 
 #      define EXTCONST extern __declspec(dllimport) const
diff --git a/INSTALL b/INSTALL
index bfdf273..c2953b8 100644 (file)
--- a/INSTALL
+++ b/INSTALL
@@ -678,7 +678,7 @@ You can elect to build a shared libperl by
 To build a shared libperl, the environment variable controlling shared
 library search (LD_LIBRARY_PATH in most systems, DYLD_LIBRARY_PATH for
 NeXTSTEP/OPENSTEP/Rhapsody, LIBRARY_PATH for BeOS, SHLIB_PATH for
-HP-UX, LIBPATH for AIX, PATH for cygwin32) must be set up to include
+HP-UX, LIBPATH for AIX, PATH for cygwin) must be set up to include
 the Perl build directory because that's where the shared libperl will
 be created.  Configure arranges makefile to have the correct shared
 library search settings.
index 82efa5d..12f987d 100644 (file)
--- a/MAINTAIN
+++ b/MAINTAIN
@@ -51,7 +51,7 @@ Porting/pumpkin.pod
 README 
 README.amiga                   amiga
 README.beos                    beos
-README.cygwin32                        cygwin32
+README.cygwin                  cygwin
 README.dos                     dos
 README.hpux                    hpux
 README.lexwarn                 lexwarn
@@ -85,7 +85,7 @@ configure.com                 vms
 configure.gnu  
 cop.h  
 cv.h   
-cygwin32/*                     cygwin32
+cygwin/*                       cygwin
 deb.c  
 djgpp/*                                dos
 doio.c 
@@ -154,7 +154,7 @@ ext/DynaLoader/DynaLoader_pm.PL
 ext/DynaLoader/Makefile.PL     
 ext/DynaLoader/README  
 ext/DynaLoader/dl_aix.xs       aix
-ext/DynaLoader/dl_cygwin32.xs  cygwin32
+ext/DynaLoader/dl_cygwin.xs    cygwin
 ext/DynaLoader/dl_dld.xs       rsanders
 ext/DynaLoader/dl_dlopen.xs    timb
 ext/DynaLoader/dl_hpux.xs      hpux
@@ -310,7 +310,7 @@ hints/broken-db.msg
 hints/bsdos.sh                 bsdos
 hints/convexos.sh      
 hints/cxux.sh                  cxux
-hints/cygwin32.sh              cygwin32x
+hints/cygwin.sh                        cygwinx
 hints/dcosx.sh 
 hints/dec_osf.sh               dec_osf
 hints/dgux.sh                  dgux
index 626dfe1..c8ef6ab 100644 (file)
@@ -303,7 +303,7 @@ ext.libs: $(static_ext)
 # Load up custom Makefile.SH fragment for shared loading and executables:
 case "$osname" in
 cygwin*)
-       Makefile_s="cygwin32/Makefile.SHs"
+       Makefile_s="cygwin/Makefile.SHs"
        ;;
 *)
        Makefile_s="$osname/Makefile.SHs"
index 8808c20..2e4a0ac 100644 (file)
@@ -499,7 +499,7 @@ sub categorize_files {
        $c{UTIL} += 10,next  if m:^(utils|x2p|h2pl)/:;
        $c{PORT1}+= 15,next  if m:^win32:;
        $c{PORT2} += 15,next
-           if m:^(cygwin32|os2|plan9|qnx|vms)/:
+           if m:^(cygwin|os2|plan9|qnx|vms)/:
            or m:^(hints|Porting|ext/DynaLoader)/:
            or m:^README\.:;
        $c{EXT}  += 10,next
index 9ca078f..fb93ac5 100644 (file)
@@ -4,13 +4,13 @@ specially designed to be readable as is.
 
 =head1 NAME
 
-README.cygwin32 - notes about porting Perl to Cygwin32
+README.cygwin - notes about porting Perl to Cygwin
 
 =head1 SYNOPSIS
 
 =over
 
-=item Cygwin32
+=item Cygwin
 
 The Cygwin tools are ports of the popular GNU development tools for
 Windows NT, 95, and 98.  They run thanks to the Cygwin library which
@@ -20,7 +20,7 @@ http://sourceware.cygnus.com/cygwin/
 
 =item libperl.dll
 
-These instructions and the default cygwin32 hints build a shared
+These instructions and the default cygwin hints build a shared
 libperl.dll Perl library and enables dynamically loaded extensions.
 
 =back
@@ -209,7 +209,7 @@ kill 'CONT', $$ if($^O =~ /cygwin/); # XXX: Cygwin bug INT signal gets stuck
 
 =head2 Configure
 
-Check hints/cygwin32.sh for any system specific settings.  In
+Check hints/cygwin.sh for any system specific settings.  In
 particular change libpth to point to the correct location of
 ...../i586-cygwin32/lib.
 
@@ -228,7 +228,7 @@ When confronted with this prompt:
 
 =end text
 
-select "cygwin32".
+select "cygwin".
 
 Do not use the malloc that comes with perl--using the perl malloc
 collides with some cygwin startup routines. 
index 6f7af54..3d37330 100644 (file)
@@ -32,7 +32,7 @@ particular, you can safely ignore any information that talks about
 "Configure".
 
 You may also want to look at two other options for building
-a perl that will work on Windows NT:  the README.cygwin32 and
+a perl that will work on Windows NT:  the README.cygwin and
 README.os2 files, which each give a different set of rules to build
 a Perl that will work on Win32 platforms.  Those two methods will
 probably enable you to build a more Unix-compatible perl, but you
diff --git a/perl.h b/perl.h
index 7414463..8ff2199 100644 (file)
--- a/perl.h
+++ b/perl.h
@@ -1644,7 +1644,7 @@ typedef pthread_key_t     perl_key;
 #   endif
 #endif
 
-#if defined(CYGWIN32)
+#if defined(CYGWIN)
 /* USEMYBINMODE
  *   This symbol, if defined, indicates that the program should
  *   use the routine my_binmode(FILE *fp, char iotype) to insure
@@ -1674,18 +1674,6 @@ union any {
 #define ARGSproto
 #endif /* USE_THREADS */
 
-#if defined(CYGWIN32)
-/* USEMYBINMODE
- *   This symbol, if defined, indicates that the program should
- *   use the routine my_binmode(FILE *fp, char iotype) to insure
- *   that a file is in "binary" mode -- that is, that no translation
- *   of bytes occurs on read or write operations.
- */
-#define USEMYBINMODE / **/
-#define my_binmode(fp, iotype) \
-        (PerlLIO_setmode(PerlIO_fileno(fp), O_BINARY) != -1 ? TRUE : FALSE)
-#endif
-
 typedef I32 (*filter_t) (pTHXo_ int, SV *, int);
 
 #define FILTER_READ(idx, sv, len)  filter_read(idx, sv, len)
@@ -2497,7 +2485,7 @@ struct perl_vars {
 EXT struct perl_vars PL_Vars;
 EXT struct perl_vars *PL_VarsPtr INIT(&PL_Vars);
 #else /* PERL_CORE */
-#if !defined(__GNUC__) || !(defined(WIN32) || defined(CYGWIN32))
+#if !defined(__GNUC__) || !(defined(WIN32) || defined(CYGWIN))
 EXT
 #endif /* WIN32 */
 struct perl_vars *PL_VarsPtr;
index 87696fe..0275543 100644 (file)
@@ -226,7 +226,7 @@ http://www.perl.com/CPAN/src/index.html
         1) in DOS mode either the DOS or OS/2 ports can be used
         2) formerly known as MVS
         3) formerly known as Digital UNIX and before that DEC OSF/1     
-        4) compilers: Borland, Cygwin32, Mingw32 EGCS/GCC, VC++
+        4) compilers: Borland, Cygwin, Mingw32 EGCS/GCC, VC++
                                         
 The following platforms have been known to build Perl from source,
 but we haven't been able to verify their status for the current release,
index 5c0c71c..6b532f3 100644 (file)
@@ -663,8 +663,8 @@ C<ftp://hobbes.nmsu.edu/pub/os2/dev/emx>
 
 =item The ActiveState Pages, C<http://www.activestate.com/>
 
-=item The Cygwin32 environment for Win32; L<README.cygwin32>,
-C<http://www.cygnus.com/misc/gnu-win32/>
+=item The Cygwin environment for Win32; L<README.cygwin>,
+C<http://sourceware.cygnus.com/cygwin/>
 
 =item The U/WIN environment for Win32,
 C<http://www.research.att.com/sw/tools/uwin/>
index 5b421db..76a5210 100644 (file)
--- a/pp_sys.c
+++ b/pp_sys.c
@@ -3543,7 +3543,7 @@ PP(pp_fork)
 
 PP(pp_wait)
 {
-#if !defined(DOSISH) || defined(OS2) || defined(WIN32) || defined(CYGWIN32)
+#if !defined(DOSISH) || defined(OS2) || defined(WIN32) || defined(CYGWIN)
     djSP; dTARGET;
     Pid_t childpid;
     int argflags;
@@ -3559,7 +3559,7 @@ PP(pp_wait)
 
 PP(pp_waitpid)
 {
-#if !defined(DOSISH) || defined(OS2) || defined(WIN32) || defined(CYGWIN32)
+#if !defined(DOSISH) || defined(OS2) || defined(WIN32) || defined(CYGWIN)
     djSP; dTARGET;
     Pid_t childpid;
     int optype;
@@ -4732,7 +4732,7 @@ PP(pp_gpwent)
 PP(pp_spwent)
 {
     djSP;
-#if defined(HAS_PASSWD) && defined(HAS_SETPWENT) && !defined(CYGWIN32)
+#if defined(HAS_PASSWD) && defined(HAS_SETPWENT) && !defined(CYGWIN)
     setpwent();
 #   ifdef HAS_SETSPENT
     setspent();
diff --git a/util.c b/util.c
index 6fc3d8f..87ebb55 100644 (file)
--- a/util.c
+++ b/util.c
@@ -1783,7 +1783,7 @@ Perl_vwarner(pTHX_ U32  err, const char* pat, va_list* args)
 }
 
 #ifndef VMS  /* VMS' my_setenv() is in VMS.c */
-#if !defined(WIN32) && !defined(CYGWIN32)
+#if !defined(WIN32) && !defined(CYGWIN)
 void
 Perl_my_setenv(pTHX_ char *nam, char *val)
 {
@@ -1848,8 +1848,8 @@ Perl_my_setenv(pTHX_ char *nam, char *val)
 #endif  /* PERL_USE_SAFE_PUTENV */
 }
 
-#else /* WIN32 || CYGWIN32 */
-#if defined(CYGWIN32)
+#else /* WIN32 || CYGWIN */
+#if defined(CYGWIN)
 /*
  * Save environ of perl.exe, currently Cygwin links in separate environ's
  * for each exe/dll.  Probably should be a member of impure_ptr.
@@ -2547,7 +2547,7 @@ Perl_my_pclose(pTHX_ PerlIO *ptr)
 }
 #endif /* !DOSISH */
 
-#if  !defined(DOSISH) || defined(OS2) || defined(WIN32) || defined(CYGWIN32)
+#if  !defined(DOSISH) || defined(OS2) || defined(WIN32) || defined(CYGWIN)
 I32
 Perl_wait4pid(pTHX_ int pid, int *statusp, int flags)
 {
diff --git a/XSUB.h b/XSUB.h
index 15f2b41..0389201 100644 (file)
--- a/XSUB.h
+++ b/XSUB.h
@@ -1,6 +1,6 @@
 #define ST(off) PL_stack_base[ax + (off)]
 
-#if defined(CYGWIN32) && defined(USE_DYNAMIC_LOADING)
+#if defined(CYGWIN) && defined(USE_DYNAMIC_LOADING)
 #  define XS(name) __declspec(dllexport) void name(pTHXo_ CV* cv)
 #else
 #  define XS(name) void name(pTHXo_ CV* cv)
index e4beabe..e6a604d 100644 (file)
@@ -26,18 +26,18 @@ addtopath=`pwd`
 $spitshell >>Makefile <<!GROK!THIS!
 
 # shell script feeding perlld to decent perl
-ld2: $& Makefile perlld ${src}/cygwin32/ld2.in
+ld2: $& Makefile perlld ${src}/cygwin/ld2.in
        @echo "extracting ld2 (with variable substitutions)"
-       @$sed s,@buildpath@,$addtopath,g <${src}/cygwin32/ld2.in >ld2
+       @$sed s,@buildpath@,$addtopath,g <${src}/cygwin/ld2.in >ld2
        @echo "installing ld2 into $installbin"
 # install is included in Cygwin distributions, and we make a note of th
# requirement in the README.cygwin32 file. However, let's give them
 # a warning.
        @if test -n "`type $1 2>&1 | sed -n -e '/'$1'$/p'`" ; then \
                install -c -m 755 ld2 ${installbin}/ld2 ; \
        else \
                echo "*************************************************" ; \
-               echo "Oh, no! You didn't read the README.cygwin32" ; \
+               echo "Oh, no! You didn't read the README.cygwin" ; \
                echo "file, which stated that \"install\" was required." ; \
                echo "Make will probably fail in a few more steps." ; \
                echo "When it does, copy \"ld2\" to a directory in" ; \
@@ -67,14 +67,14 @@ EXPORT_ALL = 1
 DEF_EXT = .def
 EXP_EXT = .exp
 
-perlld: $& Makefile ${src}/cygwin32/perlld.in
+perlld: $& Makefile ${src}/cygwin/perlld.in
        @echo "extracting perlld (with variable substitutions)"
        @$sed -e s,@CC@,\${CC}, -e s,@DLLWRAP@,\${DLLWRAP},g \\
        -e s,@WRAPDRIVER@,\${WRAPDRIVER},g -e s,@DLLTOOL@,\${DLLTOOL},g \\
        -e s,@AS@,\${AS},g -e s,@EXPORT_ALL@,\${EXPORT_ALL},g \\
        -e s,@DEF_EXT@,\${DEF_EXT},g -e s,@EXP_EXT@,\${EXP_EXT},g \\
        -e s,@LIB_EXT@,\${LIB_EXT},g \\
-       ${src}/cygwin32/perlld.in >perlld
+       ${src}/cygwin/perlld.in >perlld
 
 !GROK!THIS!
 
index 6a2b0fe..0054afa 100644 (file)
@@ -1,4 +1,4 @@
-/* dl_cygwin32.xs
+/* dl_cygwin.xs
  * 
  * Platform:   Win32 (Windows NT/Windows 95)
  * Author:     Wei-Yuen Tan (wyt@hip.com)
@@ -8,7 +8,7 @@
  *    August 23rd 1995 - rewritten after losing everything when I
  *                       wiped off my NT partition (eek!)
  */
-/* Modified from the original dl_win32.xs to work with cygwin32
+/* Modified from the original dl_win32.xs to work with cygwin
    -John Cerney 3/26/97
 */
 /* Porting notes:
@@ -21,7 +21,7 @@ calls.
 
 #define WIN32_LEAN_AND_MEAN
 // Defines from windows needed for this function only. Can't include full
//  Cygwin32 windows headers because of problems with CONTEXT redefinition
 //  Removed logic to tell not dynamically load static modules. It is assumed that all
 //   modules are dynamically built. This should be similar to the behavoir on sunOS.
 //   Leaving in the logic would have required changes to the standard perlmain.c code
index 8f0c3b7..9cca0e3 100644 (file)
    }
 #  define times(t) vms_times(t)
 #else
-#if defined (CYGWIN32)
+#if defined (CYGWIN)
 #    define tzname _tzname
 #    undef MB_CUR_MAX          /* XXX: bug in b20.1 */
 #endif
index 24deb77..a30894b 100644 (file)
@@ -8,7 +8,7 @@
  */
 
 #include "config.h"
-#ifdef CYGWIN32
+#ifdef CYGWIN
 # define EXT extern
 # define EXTCONST extern const
 #else
index 7d68892..e6d466b 100644 (file)
@@ -1,6 +1,5 @@
 #! /bin/sh
-# cygwin32.sh - hintsfile for building perl on Windows NT using the
-#     Cygnus Win32 Development Kit.
+# cygwin.sh - hints for building perl using the Cygwin environment for Win32
 #
 
 _exe='.exe'
@@ -10,16 +9,16 @@ firstmakefile='GNUmakefile'
 sharpbang='#!'
 startsh='#!/bin/sh'
 
-archname='cygwin32'
+archname='cygwin'
 cc='gcc'
 libpth='/usr/i586-cygwin32/lib /usr/lib /usr/local/lib'
 so='dll'
 libs='-lcygwin -lm -lkernel32'
 #optimize='-g'
-ccflags='-DCYGWIN32 -I/usr/include -I/usr/local/include'
+ccflags='-DCYGWIN -I/usr/include -I/usr/local/include'
 ldflags='-L/usr/i586-cygwin32/lib -L/usr/lib -L/usr/local/lib'
 usemymalloc='n'
-dlsrc='dl_cygwin32.xs'
+dlsrc='dl_cygwin.xs'
 cccdlflags=' '
 ld='ld2'
 lddlflags='-L/usr/local/lib'
@@ -29,7 +28,6 @@ dlext='dll'
 
 man1dir=/usr/local/man/man1
 man3dir=/usr/local/man/man3
-sitelib=/usr/local/lib/perl5/site_perl
 
 case "$ldlibpthname" in
 '') ldlibpthname=PATH ;;
index df4ae59..7a92290 100644 (file)
@@ -24,7 +24,7 @@ sub cflags {
       / *= */ and $self->{$`} = $';
     };
     $self->{CCFLAGS} .= " -DUSEIMPORTLIB" if ($Config{useshrplib} eq 'true');
-    $self->{CCFLAGS} .= " -DCYGWIN32" unless ($self->{CCFLAGS} =~ /\-DCYGWIN32/);
+    $self->{CCFLAGS} .= " -DCYGWIN" unless ($self->{CCFLAGS} =~ /\-DCYGWIN/);
 
     return $self->{CFLAGS} = qq{
 CCFLAGS = $self->{CCFLAGS}
index e1c2846..f03f68b 100755 (executable)
@@ -105,7 +105,7 @@ for file in `$cat .clist`; do
                if [ "$osname" = os2 ]; then
                        uwinfix="-e s,\\\\\\\\,/,g"
                else
-                       if [ "$archname" = cygwin32 ]; then
+                       if [ "$archname" = cygwin ]; then
                                uwinfix="-e s,\\\\\\\\,/,g"
                        else
                                uwinfix=
@@ -26,18 +26,18 @@ addtopath=`pwd`
        @echo "installing ld2 into $installbin"
 # install is included in Cygwin distributions, and we make a note of th
-# requirement in the README.cygwin32 file. However, let's give them
+# requirement in the README.cygwin file. However, let's give them
 # a warning.
        @if test -n "`type $1 2>&1 | sed -n -e '/'$1'$/p'`" ; then \
@@ -21,7 +21,7 @@ calls.
 #define WIN32_LEAN_AND_MEAN
 // Defines from windows needed for this function only. Can't include full
-//  Cygwin32 windows headers because of problems with CONTEXT redefinition
+//  Cygwin windows headers because of problems with CONTEXT redefinition
 //  Removed logic to tell not dynamically load static modules. It is assumed that all
 //   modules are dynamically built. This should be similar to the behavoir on sunOS.